summaryrefslogtreecommitdiffstats
path: root/remoting/protocol/host_control_dispatcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'remoting/protocol/host_control_dispatcher.h')
-rw-r--r--remoting/protocol/host_control_dispatcher.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/remoting/protocol/host_control_dispatcher.h b/remoting/protocol/host_control_dispatcher.h
index 2bda655..fab197d 100644
--- a/remoting/protocol/host_control_dispatcher.h
+++ b/remoting/protocol/host_control_dispatcher.h
@@ -18,18 +18,26 @@ namespace remoting {
namespace protocol {
class BufferedSocketWriter;
+class ClipboardStub;
class ControlMessage;
class HostStub;
class Session;
// HostControlDispatcher dispatches incoming messages on the control
// channel to HostStub, and also implements ClientStub for outgoing
// messages.
class HostControlDispatcher : public ChannelDispatcherBase, public ClientStub {
public:
HostControlDispatcher();
virtual ~HostControlDispatcher();
+ // Sets the ClipboardStub that will be called for each incoming clipboard
+ // message. Doesn't take ownership of |clipboard_stub|, which must outlive
+ // the dispatcher.
+ void set_clipboard_stub(ClipboardStub* clipboard_stub) {
+ clipboard_stub_ = clipboard_stub;
+ }
+
// Sets HostStub that will be called for each incoming control
// message. Doesn't take ownership of |host_stub|. It must outlive
// this dispatcher.
@@ -43,6 +51,7 @@ class HostControlDispatcher : public ChannelDispatcherBase, public ClientStub {
void OnMessageReceived(ControlMessage* message,
const base::Closure& done_task);
+ ClipboardStub* clipboard_stub_;
HostStub* host_stub_;
ProtobufMessageReader<ControlMessage> reader_;
@@ -18,18 +18,26 @@ namespace remoting {
class Session;
// HostControlDispatcher dispatches incoming messages on the control
-// channel to HostStub, and also implements ClientStub for outgoing
-// messages.
+// channel to HostStub or ClipboardStub, and also implements ClientStub for
+// outgoing messages.
class HostControlDispatcher : public ChannelDispatcherBase, public ClientStub {
public: